@@ -2,9 +2,7 @@
 #'
 #' Interface to interest and FX rates as published by the Czech National Bank.
 #'
-#'
-#' @docType package
-#' @name czechrates-package
+#' @name czechrates
 #' @keywords internal
 #' @importFrom magrittr %>%
 
@@ -12,3 +10,4 @@ globalVariables(names = c("date_valid", "valid_from", "valid_to",
                           "fake", "currency", "X1", "amount", "currency_code",
                           "name", "rate", "starts_with"))
 
+"_PACKAGE"
